@@ -130,6 +130,13 @@ def Alarm(engine,priv,alarm):
     print("ALARM")
     print(alarm) 
 
+#
+# Called whenever the tether state of the system changes.
+#
+def Tether(engine,priv,state):
+    print("New Tether State: "+str(state))
+    print()
+
 # ############################################################################
 #
 # Event Loop
@@ -146,6 +153,7 @@ engine.setAddCallback(ObjectAdded)
 engine.setDeleteCallback(ObjectDeleted)
 engine.setChangeCallback(ObjectChanged)
 engine.setAlarmCallback(Alarm)
+engine.setTetherCallback(Tether)
 
 #
 # Start the engine, giving the hostname/address of the Drouter service.
