@@ -124,7 +124,10 @@ int EndPointMap::quantity(EndPointMap::Type type) const
 
 QHostAddress EndPointMap::hostAddress(EndPointMap::Type type,int n) const
 {
-  return map_host_addresses[type].at(n);
+  if(n<map_host_addresses[type].size()) {
+    return map_host_addresses[type].at(n);
+  }
+  return QHostAddress();
 }
 
 
@@ -142,7 +145,10 @@ void EndPointMap::setHostAddress(EndPointMap::Type type,int n,const QString &add
 
 int EndPointMap::slot(EndPointMap::Type type,int n) const
 {
-  return map_slots[type].at(n);
+  if(n<map_slots[type].size()) {
+    return map_slots[type].at(n);
+  }
+  return -1;
 }
 
 
@@ -152,6 +158,26 @@ void EndPointMap::setSlot(EndPointMap::Type type,int n,int slot)
 }
 
 
+QString EndPointMap::name(EndPointMap::Type type,int n,const QString &orig_name) const
+{
+  QString ret;
+
+  if(n<map_names[type].size()) {
+    ret=map_names[type].at(n);
+  }
+  if(ret.isEmpty()) {
+    ret=orig_name;
+  }
+  return ret;
+}
+
+
+void EndPointMap::setName(EndPointMap::Type type,int n,const QString &str)
+{
+  map_names[type][n]=str;
+}
+
+
 int EndPointMap::endPoint(Type type,const QHostAddress &hostaddr,int slot) const
 {
   for(int i=0;i<map_host_addresses[type].size();i++) {
@@ -170,17 +196,21 @@ int EndPointMap::endPoint(Type type,const QString &hostaddr,int slot) const
 }
 
 
-void EndPointMap::insert(EndPointMap::Type type,int n,const QHostAddress &host_addr,int slot)
+void EndPointMap::insert(EndPointMap::Type type,int n,const QHostAddress &host_addr,int slot,
+			 const QString &name)
 {
   map_host_addresses[type].insert(n,host_addr);
   map_slots[type].insert(n,slot);
+  map_names[type].insert(n,name);
 }
 
 
-void EndPointMap::insert(EndPointMap::Type type,int n,const QString &host_addr,int slot)
+void EndPointMap::insert(EndPointMap::Type type,int n,const QString &host_addr,int slot,
+			 const QString &name)
 {
   map_host_addresses[type].insert(n,QHostAddress(host_addr));
   map_slots[type].insert(n,slot);
+  map_names[type].insert(n,name);
 }
 
 
@@ -247,6 +277,8 @@ bool EndPointMap::load(const QString &filename,QStringList *unused_lines)
       map_host_addresses[type].push_back(addr);
       map_slots[type].push_back(p->intValue(EndPointMap::typeString(type)+
 	       QString().sprintf("%d",count+1),"Slot")-1);
+      map_names[type].push_back(p->stringValue(EndPointMap::typeString(type)+
+	       QString().sprintf("%d",count+1),"Name"));
       count++;
       addr=p->addressValue(EndPointMap::typeString(type)+
 	       QString().sprintf("%d",count+1),"HostAddress",QHostAddress(),&ok);
@@ -292,7 +324,7 @@ bool EndPointMap::load(const QString &filename,QStringList *unused_lines)
 }
 
 
-bool EndPointMap::save(const QString &filename) const
+bool EndPointMap::save(const QString &filename,bool incl_names) const
 {
   QString tempname=filename+"-temp";
   FILE *f=NULL;
@@ -300,7 +332,7 @@ bool EndPointMap::save(const QString &filename) const
   if((f=fopen(tempname.toUtf8(),"w"))==NULL) {
     return false;
   }
-  save(f);
+  save(f,incl_names);
   fclose(f);
   if(rename(tempname.toUtf8(),filename.toUtf8())!=0) {
     unlink(tempname.toUtf8());
@@ -311,7 +343,7 @@ bool EndPointMap::save(const QString &filename) const
 }
 
 
-void EndPointMap::save(FILE *f) const
+void EndPointMap::save(FILE *f,bool incl_names) const
 {
   fprintf(f,"[Global]\n");
   fprintf(f,"RouterType=%s\n",
@@ -332,6 +364,14 @@ void EndPointMap::save(FILE *f) const
 	      (const char *)map_host_addresses[type].at(j).toString().toUtf8());
       }
       fprintf(f,"Slot=%d\n",map_slots[type].at(j)+1);
+      if(incl_names) {
+	fprintf(f,"Name=%s\n",
+		(const char *)map_names[type].at(j).toUtf8());
+      }
+      else {
+	fprintf(f,"; Name=%s\n",
+		(const char *)map_names[type].at(j).toUtf8());
+      }
       fprintf(f,"\n");
     }
   }
