@@ -25,8 +25,11 @@
 #include <QObject>
 #include <QTimer>
 
+#include "config.h"
 #include "drouter.h"
+#include "exitnotifier.h"
 #include "scriptengine.h"
+#include "tether.h"
 
 #define DROUTERD_PROTOCOL_START_INTERVAL 30000
 #define DROUTERD_USAGE "[--no-scripts]\n"
@@ -40,6 +43,8 @@ class MainObject : public QObject
  private slots:
   void protocolData();
   void scriptsData();
+  void instanceStateChangedData(bool this_state);
+  void exitData();
 
  private:
   DRouter *main_drouter;
@@ -49,6 +54,9 @@ class MainObject : public QObject
   bool main_no_scripts;
   QTimer *main_scripts_timer;
   ScriptEngine *main_script_engine;
+  ExitNotifier *main_exit_notifier;
+  Tether *main_tether;
+  Config *main_config;
 };
 
 
